from typing import Optional
from datetime import datetime
from pydantic import BaseModel, EmailStr


# Shared properties
class SupplierBase(BaseModel):
    name: str
    contact_name: Optional[str] = None
    email: Optional[EmailStr] = None
    phone: Optional[str] = None
    address: Optional[str] = None


# Properties to receive on supplier creation
class SupplierCreate(SupplierBase):
    pass


# Properties to receive on supplier update
class SupplierUpdate(SupplierBase):
    name: Optional[str] = None


# Properties shared by models stored in DB
class SupplierInDBBase(SupplierBase):
    id: int
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        orm_mode = True


# Properties to return to client
class Supplier(SupplierInDBBase):
    pass


# Properties properties stored in DB
class SupplierInDB(SupplierInDBBase):
    pass